.. LTEpy documentation master file, created by
   sphinx-quickstart on Wed Jul 12 14:05:25 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

LTEpy
=======

Hello! Welcome to the documentation for ``LTEpy``, a convenient Python package for calculating
and visualizing properties of a system in (local) thermodynamic equilibrium, or LTE.

``LTEpy`` currently supports the following basic LTE calculations:

* The Planck Function for black body radiation
* The Maxwell Boltzmann Distribution
* The Boltzmann Factors for an atom's energy levels


User Guide:
+++++++++++

.. toctree::
   :maxdepth: 2

   installation
   examples
   api


Changelog:
+++++++++++

**1.0.2 (2023-07-15)**

- Fixed plotting style sheet bug

**1.0.1 (2023-07-15)**

- Fixed install requirements bug

**1.0.0 (2023-07-15)**

- Initial release


Indices and Tables
++++++++++++++++++

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
